import java.util.Scanner;

public class Driver {
    private static MusicCollection pop = new MusicCollection(new MusicPlayer());
    private static MusicCollection rock = new MusicCollection(new MusicPlayer());
    private static MusicCollection jazz = new MusicCollection(new MusicPlayer());
    private static MusicCollection country = new MusicCollection(new MusicPlayer());

    private static MusicCollection favorites = new MusicCollection(new MusicPlayer());
    private static MusicCollection searchResults = new MusicCollection(new MusicPlayer());

    private static int playingFolder=-1;
    private static int playingIndex=-1;

    /**
     * this is the main driver for our program
     * @param args given args in console
     *
     */
    public static void main(String[] args) {
        Scanner scanner = new Scanner(System.in);
        int order = -1;
        while (order != 0) {
            System.out.println("""
                    Welcome To MyPlayer!

                    1- Play From Library
                    2- Add Music
                    3- List Musics
                    4- Stop Playing
                    0- Exit
                    """);
            order = scanner.nextInt();
            switch (order) {
                case 1 -> playFromLibrary();
                case 2 -> addMusic();
                case 3 -> listMusics();
                case 4 -> stopPlayer();
                case 0 -> System.out.println("FareWell!");
                default -> System.out.println("WRONG ENTRY!");
            }

            clearScreen();
        }
    }

    /**
     * Stop the file which is being played
     */
    private static void stopPlayer() {
        if (playingFolder!=-1 && playingIndex!=-1)
            switch (playingFolder){
                case (0) -> pop.stopPlaying();
                case (1) -> rock.stopPlaying();
                case (2) -> jazz.stopPlaying();
                case (3) -> country.stopPlaying();
                case (4) -> favorites.stopPlaying();
            }
        else
            System.out.println("No File Is Being Played!");
    }

    /**
     * shows a list of all music tracks in any willing folder
     */
    private static void listMusics() {
        System.out.println("Please Choose Genre:");
        Scanner scanner=new Scanner(System.in);
        int genre = scanner.nextInt();
        switch (genre){
            case (0) -> pop.listAllFiles();
            case (1) -> rock.listAllFiles();
            case (2) -> jazz.listAllFiles();
            case (3) -> country.listAllFiles();
            case (4) -> favorites.listAllFiles();
        }
    }


    /**
     * method to add a music track to the list
     */
    private static void addMusic() {

        Scanner scanner = new Scanner(System.in);
        Music track = new Music();

        System.out.println("Please Enter:\nMusic Genre:\n0- Pop\n1-Rock\n2-Jazz\n3-Country\n");
        int genre = scanner.nextInt();

        System.out.println("Music Name:");
        scanner.nextLine();
        String name = scanner.nextLine();

        System.out.println("Music Artist:");
        String artist = scanner.nextLine();

        System.out.println("Music Release Year:");
        int year = scanner.nextInt();
        scanner.nextLine();

        System.out.println("Music Directory:");
        String dir = scanner.nextLine();

        track.setName(name);
        track.setArtist(artist);
        track.setDistributionYear(year);
        track.setFileDirectory(dir);

        switch (genre){
            case (0) -> pop.addFile(track);
            case (1) -> rock.addFile(track);
            case (2) -> jazz.addFile(track);
            case (3) -> country.addFile(track);
        }
    }

    /**
     * method to play a music track from any willing folder
     */
    private static void playFromLibrary() {
        Scanner scanner = new Scanner(System.in);
        int folder;
        clearScreen();
        System.out.println("""
                Please Choose Library...
                                            
                0- Pop
                1- Jazz
                2- Rock
                3- Country
                4- Favorites
                """);
        folder = scanner.nextInt();
        clearScreen();
        System.out.println("1- Play By Index\n2- Search");

        int order = scanner.nextInt();

        if (order == 1) {
            System.out.println("Please Enter The Index...");
            int index = scanner.nextInt();
            switch (folder){
                case (0) -> pop.startPlaying(index);
                case (1) -> rock.startPlaying(index);
                case (2) -> jazz.startPlaying(index);
                case (3) -> country.startPlaying(index);
            }
            playingFolder=folder;
            playingIndex=index;

        } else if (order == 2) {

            System.out.println("Enter Keyword");
            String keyWord = scanner.next();
            switch (folder){
                case (0) -> searchResults=pop.search(keyWord);
                case (1) -> searchResults=rock.search(keyWord);
                case (2) -> searchResults=jazz.search(keyWord);
                case (3) -> searchResults=country.search(keyWord);
            }

            searchResults.listAllFiles();

            System.out.println("Please Enter Track Index To Be Chosen...");
            int index = scanner.nextInt();

            System.out.println("1- Play\n2- Add To Favorites");
            int order2 = scanner.nextInt();

            if (order2 == 1)
                searchResults.startPlaying(index);
            else if (order2 == 2)
                favorites.addFile(searchResults.getFile(index-1));
        }

    }

    /**
     * if we run the program in Command Prompt, this method will erase the whole console
     */
    public static void clearScreen() {
        System.out.print("\033[H\033[2J");
        System.out.flush();
    }
}
